==> MeaningCloud_python-1.0.0-py2.py3-none-any.whl: meaningcloud/SentimentRequest.py <==
import meaningcloud.Request


class SentimentRequest(meaningcloud.Request):
    URL = 'http://api.meaningcloud.com/sentiment-2.1'
    otherparams = None
    extraheaders = None
    type_ = ""

    # SentimentRequest constructor
    # @param string url URL of the API against which the request will be made
    # @param string key license key
    # @param string lang . Language used in the request
    # @param string txt . Text to use in the API calls
    # @param string url . Text to use in the API calls
    # @param string doc . Text to use in the API calls
    # @param string txtf . Format of the text
    # @params array otherparams . Array where can be added other params to use in the API call
    # @params array extraheaders . Array where can be added other headers used in the request


    def __init__(self, key, lang=None, txt=None, txtf='plain', url=None, doc=None, otherparams=None, extraheaders=None):
        self._params = {}
        meaningcloud.Request.__init__(self, self.URL, key)

        self.otherarams = otherparams
        self.extraheaders = extraheaders
        self._url = self.URL


        self.addParam('key', key)
        self.addParam('lang', lang)
        self.addParam('txtf', txtf)

        if txt:
            type_ = 'txt'
        elif doc:
            type_ = 'doc'
        elif url:
            type_ = 'url'
        else:
            type_ = 'default'

        options = {'doc': lambda: self.setContentFile(doc),
                   'url': lambda: self.setContentUrl(url),
                   'txt': lambda: self.setContentTxt(txt),
                   'default': lambda: self.setContentTxt(txt)
                   }
        options[type_]()

        if (otherparams):
            for key in otherparams:
                self.addParam(key, otherparams[key])


    def sendReq(self):

        return self.sendRequest(self.extraheaders)

==> MeaningCloud_python-1.2.0-py2.py3-none-any.whl: meaningcloud/SentimentRequest.py <==
import meaningcloud.Request


class SentimentRequest(meaningcloud.Request):
    URL = 'https://api.meaningcloud.com/sentiment-2.1'
    otherparams = None
    extraheaders = None
    type_ = ""

    def __init__(self, key, lang=None, txt=None, txtf='plain', url=None, doc=None, otherparams=None, extraheaders=None):
        """
        SentimentRequest constructor

        :param key:
            License key
        :param lang:
            Language used in the request
        :param txt:
            Text to use in the API calls
        :param txtf:
            Format of the text
        :param url:
            Url to use in the API calls
        :param doc:
            File to use in the API calls
        :param otherparams:
            Array where other params can be added to be used in the API call
        :param extraheaders:
            Array where other headers can be added to be used in the request
        """

        self._params = {}
        meaningcloud.Request.__init__(self, self.URL, key)

        self.otherarams = otherparams
        self.extraheaders = extraheaders
        self._url = self.URL

        self.addParam('key', key)
        self.addParam('lang', lang)
        self.addParam('txtf', txtf)

        if txt:
            type_ = 'txt'
        elif doc:
            type_ = 'doc'
        elif url:
            type_ = 'url'
        else:
            type_ = 'default'

        options = {'doc': lambda: self.setContentFile(doc),
                   'url': lambda: self.setContentUrl(url),
                   'txt': lambda: self.setContentTxt(txt),
                   'default': lambda: self.setContentTxt(txt)
                   }
        options[type_]()

        if otherparams:
            for key in otherparams:
                self.addParam(key, otherparams[key])

    def sendReq(self):
        return self.sendRequest(self.extraheaders)
